# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"download_url": "00_core.ipynb",
         "path_stats": "00_core.ipynb",
         "checks_module": "00_core.ipynb",
         "read_checks": "00_core.ipynb",
         "check": "00_core.ipynb",
         "update_checks": "00_core.ipynb",
         "download_and_check": "00_core.ipynb",
         "FastDownload": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://fastdownload.fast.ai/"

git_url = "https://github.com/fastai/fastdownload/tree/master/"

def custom_doc_links(name): return None
